*--------------------------------------------------------------------*
*	Creating a database of inequality measures within occupations    *
*--------------------------------------------------------------------*


* This do-file assumes that data was already prepared for the analysis following
* the set of dofiles available on 
* http://grape.org.pl/project/tasks#harmonizing-inequality-indicators
* under heading "Harmonization files"

* To run, please ensure that local path_data is a relative path to data location

ssc install ineqdeco

local path_data "..\data"

cd "`path_data'"

global datas :  dir  . files "*.dta"
local i = 0
foreach ds in $datas{
local ++i

use "`ds'" , clear
tokenize "`ds'" , parse("_" ".")

local cc	= "`7'"
local year 		= "`5'"

 
if inlist(`year',2002,2006) {
	local isco2d isco88_2d
	local isco3d isco88_3d
	}
else{	
	local isco2d isco08_2d
	local isco3d isco08_3d
	}
 
 
** Characteristics (x) 

capture replace `isco3d' =0 if `isco3d'==.


* Alternative tenure variable -- discrete less or more than 5 years

if "`cc'"=="NLD" & `year'<2008{
gen ten = 0 
replace ten =1 if b26=="Year1_4"  |  b26=="Year0_<1" 
}
else{
capture destring b26, replace force
gen ten = b26 <5
}

* Numerical nace codes

 encode nace, gen(nnace)

** Wages

if "`cc'" == "italy" &  "`year'" =="2010"{
replace hwage = hwage_own
}
capture drop lwage
gen lwage = log(hwage) 


* Residual wages

global few_x fem i.age i.educ i.size2 i.nnace overt


xi: qui reg lwage $few_x
predict rlwage , residuals

quiet unique key_l
if r(unique)>1{
	qui reg lwage $few_x , a(key_l)
	predict rflwage , residuals
	}
else gen rflwage=1					// Sweden - Finland

gen rwage = exp(rlwage)
gen fwage = exp(rflwage)


** Inequality measures (I)


foreach p in h r f{

capture drop gini_`p'
capture drop theil_`p'

gen gini_`p' = .
gen theil_`p' = .

levelsof `isco2d' , local(occ)

foreach o in `occ'{

	ineqdeco `p'wage if `isco2d' ==`o'

	replace gini_`p' = `r(gini)'  if `isco2d' ==`o'
	replace theil_`p' = `r(ge1)' if `isco2d' ==`o'
	}

}



 
collapse	(p90) p90 = hwage r90 = rlwage f90 = rflwage   ///
			(p50) p50 = hwage r50 = rlwage f50 = rflwage	///
			(p10) p10 = hwage r10 = rlwage f10 = rflwage	///
			(first) gini_h gini_r gini_f theil_h theil_r theil_f country year, by(`isco2d')

tempfile part_`i'		
save `part_`i'', replace


global lasti = `i'


}
clear
forvalues i = 1/ $lasti {
append using `part_`i''
}

replace country="EL" if country =="GR"



* Inequality measures (II)
*-------------------------------
gen l9010_h = log(p90/p10) 
gen l9050_h = log(p90/p50) 
gen l5010_h = log(p50/p10) 

encode c_code, gen(cn)
 
foreach pre in r f{ 
gen l9010_`pre' = abs(`pre'90-`pre'10)
gen l9050_`pre' = abs(`pre'90-`pre'50) 
gen l5010_`pre' = abs(`pre'50-`pre'10) 
}


*	Delete extra vars
*-----------------------------------
capture drop p?0 r?0 f?0

*	Labelling
*--------------------------------


label data "Harmonized measures of within occupation wage inequality"
note : All variables ending in _h indicate raw wage dispersion
note : All variables ending in _r indicate dispersion in residuals 
note : All variables ending in _f indicate dispersion in residuals including firm FE 

local h "Raw wages"
local r "Residuals"
local f "Res + FE"

foreach e in h r f{
label var l9010_`e' "Log(p90/p10) - ``e''"
label var l9050_`e' "Log(p90/p50) - ``e''"
label var l5010_`e' "Log(p50/p10) - ``e''"

label var gini_`e'	"Gini coeff - ``e'' "
label var theil_`e'	"Theil coeff - ``e'' "

}

label var country "Country"
label var year "Year"



save "$eu_ses/data_website" , replace
